@@ -462,7 +462,7 @@ requires various things that are set therein. */
 #include <iconv.h>
 #endif
 
-#if defined(USE_READLINE) || defined(EXPAND_DLFUNC)
+#if defined(USE_READLINE) || defined(EXPAND_DLFUNC) || defined (LOOKUP_MODULE_DIR)
 #include <dlfcn.h>
 #endif
 
@@ -533,5 +533,12 @@ default to EDQUOT if it exists, otherwise ENOSPC. */
   #endif
 #endif
 
+/* These are for reporting version information from various componenents, to
+figure out what's actually happening. They need to be available to the main
+function, so we declare them here. Unfortunate. */
+
+#ifdef AUTH_CYRUS_SASL
+extern void auth_cyrus_sasl_version_report(FILE *);
+#endif
 
 /* End of exim.h */
