@@ -1,10 +1,10 @@
-/* $Cambridge: exim/exim-src/src/lookups/dsearch.c,v 1.5 2007/05/31 12:42:07 magnus Exp $ */
+/* $Cambridge: exim/src/src/lookups/dsearch.c,v 1.6 2009/11/16 19:50:38 nm4 Exp $ */
 
 /*************************************************
 *     Exim - an Internet mail transport agent    *
 *************************************************/
 
-/* Copyright (c) University of Cambridge 1995 - 2007 */
+/* Copyright (c) University of Cambridge 1995 - 2009 */
 /* See the file NOTICE for conditions of use and distribution. */
 
 /* The idea for this code came from Matthew Byng-Maddick, but his original has
@@ -14,7 +14,6 @@ lstat()) rather than a directory scan). */
 
 #include "../exim.h"
 #include "lf_functions.h"
-#include "dsearch.h"
 
 
 
@@ -27,7 +26,7 @@ whether it exists and whether it is searchable. However, we don't need to keep
 it open, because the "search" can be done by a call to lstat() rather than
 actually scanning through the list of files. */
 
-void *
+static void *
 dsearch_open(uschar *dirname, uschar **errmsg)
 {
 DIR *dp = opendir(CS dirname);
@@ -51,7 +50,7 @@ return (void *)(-1);
 integer as this gives warnings on 64-bit systems. */
 
 BOOL
-dsearch_check(void *handle, uschar *filename, int modemask, uid_t *owners,
+static dsearch_check(void *handle, uschar *filename, int modemask, uid_t *owners,
   gid_t *owngroups, uschar **errmsg)
 {
 handle = handle;
@@ -69,7 +68,7 @@ scanning the directory, as it is hopefully faster to let the OS do the scanning
 for us. */
 
 int
-dsearch_find(void *handle, uschar *dirname, uschar *keystring, int length,
+static dsearch_find(void *handle, uschar *dirname, uschar *keystring, int length,
   uschar **result, uschar **errmsg, BOOL *do_cache)
 {
 struct stat statbuf;
@@ -115,9 +114,46 @@ return DEFER;
 /* See local README for interface description */
 
 void
-dsearch_close(void *handle)
+static dsearch_close(void *handle)
 {
 handle = handle;   /* Avoid compiler warning */
 }
 
+
+/*************************************************
+*         Version reporting entry point          *
+*************************************************/
+
+/* See local README for interface description. */
+
+#include "../version.h"
+
+void
+dsearch_version_report(FILE *f)
+{
+#ifdef DYNLOOKUP
+fprintf(f, "Library version: dsearch: Exim version %s\n", EXIM_VERSION_STR);
+#endif
+}
+
+
+static lookup_info _lookup_info = {
+  US"dsearch",                   /* lookup name */
+  lookup_absfile,                /* uses absolute file name */
+  dsearch_open,                  /* open function */
+  dsearch_check,                 /* check function */
+  dsearch_find,                  /* find function */
+  dsearch_close,                 /* close function */
+  NULL,                          /* no tidy function */
+  NULL,                          /* no quoting function */
+  dsearch_version_report         /* version reporting */
+};
+
+#ifdef DYNLOOKUP
+#define dsearch_lookup_module_info _lookup_module_info
+#endif
+
+static lookup_info *_lookup_list[] = { &_lookup_info };
+lookup_module_info dsearch_lookup_module_info = { LOOKUP_MODULE_INFO_MAGIC, _lookup_list, 1 };
+
 /* End of lookups/dsearch.c */
